package org.apache.bcel.util;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import org.apache.bcel.classfile.ClassParser;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.util.ClassPath;
import org.apache.bcel.util.Repository;

public class ClassLoaderRepository implements Repository {
  private final ClassLoader loader;
  
  private final Map<String, JavaClass> loadedClasses = new HashMap<>();
  
  public ClassLoaderRepository(ClassLoader loader) {
    this.loader = loader;
  }
  
  public void clear() {
    this.loadedClasses.clear();
  }
  
  public JavaClass findClass(String className) {
    return this.loadedClasses.get(className);
  }
  
  public ClassPath getClassPath() {
    return null;
  }
  
  public JavaClass loadClass(Class<?> clazz) throws ClassNotFoundException {
    return loadClass(clazz.getName());
  }
  
  public JavaClass loadClass(String className) throws ClassNotFoundException {
    String classFile = className.replace('.', '/');
    JavaClass RC = findClass(className);
    if (RC != null)
      return RC; 
    try (InputStream is = this.loader.getResourceAsStream(classFile + ".class")) {
      if (is == null)
        throw new ClassNotFoundException(className + " not found."); 
      ClassParser parser = new ClassParser(is, className);
      RC = parser.parse();
      storeClass(RC);
      return RC;
    } catch (IOException e) {
      throw new ClassNotFoundException(className + " not found: " + e, e);
    } 
  }
  
  public void removeClass(JavaClass clazz) {
    this.loadedClasses.remove(clazz.getClassName());
  }
  
  public void storeClass(JavaClass clazz) {
    this.loadedClasses.put(clazz.getClassName(), clazz);
    clazz.setRepository(this);
  }
}
